stock ProcessConfigFile(const String:file[])
{
	decl String:filepath[PLATFORM_MAX_PATH];
	BuildPath(Path_SM, filepath, sizeof(filepath), file);
	if (!FileExists(filepath))
	{
		LogToFile(LOGFILE, "Could not find %s", filepath);
		SetFailState("Could not find %s", filepath);
	}
	if (!ParseConfigFile(filepath))
	{
		LogToFile(LOGFILE, "Could not properly read %s", filepath);
		SetFailState("Could not properly read %s", filepath);
	}
	else if (!IsGametypeSet)
	{
		ChangeGameType(true);
	}
}

stock String:GameModeString()
{
	decl String:GameModeOptions[512];
	GameModeOptions = "";
	decl String:SearchKey[128];
	new aSize = GetArraySize(g_ModeKey);
	for (new i = 0; i < aSize; i++)
	{
		GetArrayString(Handle:g_ModeKey, i, SearchKey, sizeof(SearchKey));
		if (StrEqual(SearchKey, "default")) continue;
		if (StrEqual(GameModeOptions, "")) Format(GameModeOptions, sizeof(GameModeOptions), "%s", SearchKey);
		else Format(GameModeOptions, sizeof(GameModeOptions), "%s, %s", GameModeOptions, SearchKey);
	}
	return GameModeOptions;
}

stock bool:ValidGameMode(String:Parameter[])
{
	decl String:SearchKey[128];
	new aSize = GetArraySize(g_ModeKey);
	for (new i = 0; i < aSize; i++)
	{
		GetArrayString(Handle:g_ModeKey, i, SearchKey, sizeof(SearchKey));
		if (StrEqual(SearchKey, "default")) continue;
		if (StrEqual(SearchKey, Parameter)) return true;
	}
	return false;
}

stock String:FindConfig(String:Parameter[])
{
	decl String:SearchKey[128];
	new aSize = GetArraySize(g_ModeKey);
	for (new i = 0; i < aSize; i++)
	{
		GetArrayString(Handle:g_ModeKey, i, SearchKey, sizeof(SearchKey));
		if (StrEqual(SearchKey, Parameter))
		{
			GetArrayString(Handle:g_ModeValue, i, SearchKey, sizeof(SearchKey));
			return SearchKey;
		}
	}
	SetFailState("\nERROR IN /configs/teammanager/config.cfg\n\nCould not find %s Game Config.", Parameter);
	return SearchKey;
}

stock bool:ParseConfigFile(const String:file[])
{
	new Handle:hParser = SMC_CreateParser();
	new String:error[128];
	new line = 0;
	new col = 0;

	SMC_SetReaders(hParser, Config_NewSection, Config_KeyValue, Config_EndSection);
	SMC_SetParseEnd(hParser, Config_End);

	new SMCError:result = SMC_ParseFile(hParser, file, line, col);
	CloseHandle(hParser);

	if (result != SMCError_Okay)
	{
		SMC_GetErrorString(result, error, sizeof(error));
		LogToFile(LOGFILE, "Problem reading %s, line %d, col %d - error: %s", file, line, col, error);
	}

	return (result == SMCError_Okay);
}

public SMCResult:Config_NewSection(Handle:parser, const String:section[], bool:quotes)
{
	if (StrEqual(section, "Team Manager")) return SMCParse_Continue;
	return SMCParse_Continue;
}

public SMCResult:Config_KeyValue(Handle:parser, const String:key[], const String:value[], bool:ley_quotes, bool:value_quotes)
{
	PushArrayString(g_ModeKey, key);
	PushArrayString(g_ModeValue, value);

	return SMCParse_Continue;
}

public SMCResult:Config_EndSection(Handle:parser) 
{
	return SMCParse_Continue;
}

public Config_End(Handle:parser, bool:halted, bool:failed) 
{
	if (failed)
	{
		SetFailState("Plugin configuration error");
	}
}  